# frigg-worker [![Build status](https://ci.frigg.io/badges/frigg/frigg-common/)](https://ci.frigg.io/frigg/frigg-common/last/) [![Coverage status](https://ci.frigg.io/badges/coverage/frigg/frigg-common/)](https://ci.frigg.io/frigg/frigg-common/last/)

Utils used in frigg projects

## Setup
```
pip install frigg-common
```
